# -*- coding: utf-8 -*-
#
# File: MxDateIndex.py
#
# Copyright (c) 2008 by BlueDynamics Alliance, Bluedynamics KEG, Austria
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Georg Gogo. BERNHARD <gogo@bluedynamics.com>, Jens Klein
<jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

##code-section module-header #fill in your manual code here
import mx
from Globals import DTMLFile, InitializeClass
##/code-section module-header

import mx.DateTime
from Globals import DTMLFile
from zope.interface import implements
from Products.PluginIndexes.DateIndex.DateIndex import DateIndex
from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin


class MxDateIndex(DateIndex):
    """
    """

    ##code-section class-header_MxDateIndex #fill in your manual code here
    meta_type = "MxDateIndex"
    ##/code-section class-header_MxDateIndex


    def _convert( self, value, default=None ) :
        """Convert Date/Time value to our internal representation"""

        if type(value) == type('') :
            value = mx.DateTime.DateTimeFrom(value)

        if isinstance( value, mx.DateTime.mxDateTime.DateTimeType ):
            t_tup = value.tuple()
        else:
            return default

        yr = t_tup[0]
        mo = t_tup[1]
        dy = t_tup[2]
        hr = t_tup[3]
        mn = t_tup[4]

        t_val = ( ( ( ( yr * 12 + mo ) * 31 + dy ) * 24 + hr ) * 60 + mn )

        return t_val


##code-section module-footer #fill in your manual code here

InitializeClass( MxDateIndex )

def initialize(context):

    context.registerClass( \
            MxDateIndex,\
            permission='Add Pluggable Index', \
            constructors=(manage_addMxDateIndexForm,\
                          manage_addMxDateIndex),\
            icon='www/index.gif',\
            visibility=None\
            )

manage_addMxDateIndexForm = DTMLFile( 'dtml/addMxDateIndex', globals() )

def manage_addMxDateIndex( self, id, REQUEST=None, RESPONSE=None, URL3=None):
    """Add a MxDate index"""
    return self.manage_addIndex(id, 'MxDateIndex', extra=None, \
                    REQUEST=REQUEST, RESPONSE=RESPONSE, URL1=URL3)
##/code-section module-footer





# -*- coding: utf-8 -*-
#
# File: MxDateTimeWidget.py
#
# Copyright (c) 2008-2014 by BlueDynamics Alliance, Bluedynamics KEG, Austria
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Georg Gogo. BERNHARD <gogo@bluedynamics.com>, Jens Klein
<jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.Registry import registerWidget
from Products.Archetypes.Widget import TypesWidget


class MxDateTimeWidget(TypesWidget):
    """Archetypes Widget
    """

    _properties = TypesWidget._properties.copy()
    _properties.update({
        'macro': 'MxDateTimeWidget',
        'size': '30',
        'maxlength': '255',
        })

    security = ClassSecurityInfo()

registerWidget(MxDateTimeWidget,
               title='MxDateTimeWidget',
               description=('no description given'),
               used_for=('Products.Archetypes.Field.StringField',)
               )



# -*- coding: utf-8 -*-
#
# File: MxDateTimeField.py
#
# Copyright (c) 2008 by BlueDynamics Alliance, Bluedynamics KEG, Austria
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Georg Gogo. BERNHARD <gogo@bluedynamics.com>, Jens Klein
<jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

from .MxDateTimeWidget import MxDateTimeWidget
from AccessControl import ClassSecurityInfo
from Products.Archetypes.Field import ObjectField
from Products.Archetypes.Field import registerField
from mx.DateTime import DateTimeFrom
from mx.DateTime import DateTimeType
from types import StringTypes


class MxDateTimeField(ObjectField):
    """Archetypes Field
    """

    _properties = ObjectField._properties.copy()
    _properties.update({
        'type': 'mxdatetimefield',
        'widget': MxDateTimeWidget,
        })

    security = ClassSecurityInfo()
    security.declarePrivate('set')
    security.declarePrivate('get')

    def set(self, instance, value, **kwargs):
        """
        Check if value is an actual date/time value. If not, attempt
        to convert it to one; otherwise, set to None. Assign all
        properties passed as kwargs to object.
        """
        if not value:
            value = None

        if type(value) in StringTypes:
            value = DateTimeFrom(value)

        if value and type(value) != DateTimeType:
            raise ValueError("Argument to MxDateTimeField must be either "
                             "a string or a MxDateTime object, but "
                             "got: %s" % repr(value))

        ObjectField.set(self, instance, value, **kwargs)

registerField(MxDateTimeField,
              title='MxDateTimeField',
              description='')



# -*- coding: utf-8 -*-
#
# File: MxDateRangeIndex.py
#
# Copyright (c) 2008 by BlueDynamics Alliance, Bluedynamics KEG, Austria
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Georg Gogo. BERNHARD <gogo@bluedynamics.com>, Jens Klein
<jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

##code-section module-header #fill in your manual code here
from Globals import DTMLFile, InitializeClass
##/code-section module-header

import mx.DateTime
from Globals import DTMLFile, InitializeClass
from zope.interface import implements
from Products.PluginIndexes.DateRangeIndex.DateRangeIndex import DateRangeIndex
from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin


class MxDateRangeIndex(DateRangeIndex):
    """
    """

    ##code-section class-header_MxDateRangeIndex #fill in your manual code here
    meta_type = "MxDateRangeIndex"
    ##/code-section class-header_MxDateRangeIndex


    def _convertDateTime( self, value ):
        if value is None:
            return value
        if type( value ) == type( '' ):
            value = mx.DateTime.DateTimeFrom( value )
        result = int(value.ticks() / 1000 / 60) # flatten to minutes
        return result


##code-section module-footer #fill in your manual code here

def initialize(context):

    context.registerClass( \
            MxDateRangeIndex,\
            permission='Add Pluggable Index', \
            constructors=(manage_addMxDateRangeIndexForm,\
                          manage_addMxDateRangeIndex),\
            icon='www/index.gif',\
            visibility=None\
            )


InitializeClass( MxDateRangeIndex )

manage_addMxDateRangeIndexForm = DTMLFile( 'dtml/addMxDateRangeIndex', globals() )
manage_indexProperties = DTMLFile( 'dtml/manageMxDateRangeIndex', globals() )

def manage_addMxDateRangeIndex(self, id, extra=None,
        REQUEST=None, RESPONSE=None, URL3=None):
    """
        Add a mx date range index to the catalog, using the incredibly icky
        double-indirection-which-hides-NOTHING.
    """
    return self.manage_addIndex(id, 'MxDateRangeIndex', extra,
        REQUEST, RESPONSE, URL3)


##/code-section module-footer





# -*- coding: utf-8 -*-
from .mxdateindex import MxDateIndex
from .mxdaterangeindex import MxDateRangeIndex
import MxDateTimeField  # register


def initialize(context):
    """initialize product (called by zope)"""
    MxDateIndex.initialize(context)
    MxDateRangeIndex.initialize(context)



from setuptools import setup, find_packages
import os

version = '1.2'
shortdesc = 'Archetypes Field using MxDateTime'

longdesc = open(
    os.path.join(
        os.path.dirname(__file__),
        'README.rst')
    ).read()

setup(
    name='Products.MxDateTimeField',
    version=version,
    description=shortdesc,
    long_description=longdesc,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development',
        "Framework :: Plone",
    ],
    keywords='',
    author='BlueDynamics Alliance',
    author_email='dev@bluedynamics.com',
    license='GPLv2',
    url='https://pypi.python.org/pypi/Products.MxDateTimeField',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['Products'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Plone',
        'egenix-mx-base>=3.2.8',
        'setuptools',
    ],
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
